scale property
The scale value at the start of the enter animation.
Defaults to 0.8. The child scales from this value to 1.0.
Implementation
final double scale;
The scale value at the start of the enter animation.
Defaults to 0.8. The child scales from this value to 1.0.
final double scale;